
# Menghitung luas lingkaran

Library Python sederhana untuk menghitung luas lingkaran.



## Instalation
```shell
pip install linkar33423321
```

## Usage
Basic Usage:
```python
from lingkar33423321.my_class import Lingkaran

def main():
    # Gunakan library lingkar
    jari_jari = float(input("Masukkan jari-jari lingkaran: "))
    
    lingkaran = Lingkaran(jari_jari)
    luas = lingkaran.hitung_luas()

    print(f"Luas lingkaran dengan jari-jari {jari_jari} adalah: {luas}")

if __name__ == "__main__":
    main()

```


